# {= name =}

This is the {= name =} project.

# Building and installing

See the [BUILDING](BUILDING.md) document.

# Contributing

See the [CONTRIBUTING](CONTRIBUTING.md) document.

# Licensing

<!--
Please go to https://choosealicense.com/licenses/ and choose a license that
fits your needs. The recommended license for a project of this type is the
{% if exe %}GNU AGPLv3{% else %}Boost Software License 1.0{% end %}.
-->
